/******************************************************************************************************************
*Title: EFIEW ELMPS Cluster Analysis
*Created by: KWR
*Created on: March 15, 2020
*Last Modified on:  May 18, 2020
*Last Modified by:  CGK
*Purpose : Use EFIEW ELMPS Model 3  cluster analysis
*Edits 
	
*****************************************************************************************************************/
	capture log close
	
	log using "$log/EFIEW ELMPS Cluster Analysis.txt", replace

	
*****************************************************************************************************************/
*Main 	
*****************************************************************************************************************/
	
	use "$workingdata/ELMPS_model2_3.dta", clear
	
	**informal
	
	keep if formality_basic==0
	
	**create binary variables
	foreach var of varlist firm_size act1_collapsed region legal_state  kap_ firm_age relout_ non_relout_ sloc_ sex educlvl3 usocp1d_cat agegrp3 {
	
				tab `var', gen(`var'_)
		 
	
			}
	
		**Check and sort on indentifier
	isid  hhid ent_num
	sort  hhid ent_num

			
	*Cluster for 10 groups, using gower (mixed cont. and binary)	
	cluster kmedians firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk ///
	, k(10) measure(gower) name(clusdirk1) start(krandom(67348))
		
	preserve
	
	collapse informal_m3_q? [aw=weight], by(clusdirk1)
	
	 
	*Order by descending
	egen cluster=rank(-informal_m3_q1)
	
	label var cluster "Cluster of Firms"

	*Label based on analysis
	label define cluster 1 "Illiterate women-owned retail" ///
						 2	"Women-owned rural" 3 "Blue collar construction" ///
						 4 "Women-owned high-rev. urban" 5 "Blue-collar workshop" ///
						 6	"Sec. male-owned rural Upper" 7 "Sec. male-owned rural Lower" ///
						 8	"Blue collar w/ employees" 9 "Educated high-rev. small" ///
						 10	"Larger firms", modify
	
	label val cluster cluster
	
	sort cluster
	
	keep clusdirk1 cluster
	
	tempfile temp1
	save `temp1'
	
	restore
	

	
	*Merge ordered clusters back into original data
	merge m:1 clusdirk1 using `temp1', nogen
	
	des cluster
	sum cluster
	tabu cluster [aw=weight]

	
	*Checks
	tabstat  firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk [aw=weight], by(cluster) stat(mean)
	
	
	tabstat  pr_model_3 [aw=weight], by(cluster) stat(mean)
	
	tab cluster informal_m3_q1 [aw=weight], nofreq row
	tab cluster informal_m3_q2 [aw=weight], nofreq row	
	tab cluster informal_m3_q3 [aw=weight], nofreq row
	tab cluster informal_m3_q4 [aw=weight], nofreq row
	
	
	
	*Graph distribution of quartiles over clusters
	graph hbar (mean) informal_m3_q? [aw=weight],   over(cluster,   label(labsize(small))) stack ylabel(,nogrid angle(0)) ///
	ytitle("Percent of informal firms") legend(order ( 1 "Quartile 1"  2 "Quartile 2"   3 "Quartile 3" 4 "Quartile 4")  ///
	size(small) col(4) rowgap(*1.5) symysize(*.8) symxsize(*.5)  pos(12)  ring(4) region(style(none)))  ///
	graphregion(color(white) fcolor(white) icolor(white) ifcolor(white) lcolor(white) ilcolor(white)) ///
	plotregion(margin(zero) color(white) fcolor(white) icolor(white) ifcolor(white) lcolor(white) ///
	ilcolor(white)) bar(1, color(gs11)) bar(2, color(gs8)) bar(3, color(gs4)) bar(4, color(gs0)) ///
	blabel(bar,format(%9.0f) position(center) size(vsmall) color(gs14))
	
		
	forval l=1/10 {
	
			forval j =1/4 {
	
					local i =  `j'+(10-`l')*4 
							
					foreach var of varlist informal_m3_q`j'    {
										
								sum `var' if cluster==`l' [aw=weight]  
										
								if r(mean)<2 {
									
										di "`l'"
										
										gr_edit .plotregion1.barlabels[`i'].Delete barlabels[`i'] edits
										
									}
							
							}
							}
		
				}
			
			

	 
	graph save "${output}/ELMPS Informal Firms by Cluster.gph", replace
	graph export "${output}/ELMPS Informal Firms by Cluster.png", width(1500) replace			
 
	 
	**normalize variables for descriptives
	
	preserve 
	
	expand 2, gen(total)
	
	replace cluster=100 if total==1
	
	collapse (mean) firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk (sd) sd_ln_rev_wrk=ln_rev_wrk  [aw=weight], by(cluster round)
	
	drop if cluster==.
	
	sort round cluster
	
	*Ratio to mean for binary
	foreach var of varlist firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? {
	
				bys round: gen norm_`var'=`var'/`var'[_N] 

			}
	*Continuous standardized		
	foreach var of varlist ln_rev_wrk {
	
				bys round: gen std_`var'=(`var'-`var'[_N])/sd_`var'[_N]

			}	
			
	drop if cluster==100 
	
	tempfile temp2
	save `temp2'
	
	restore
	
	*Merging back in clusters
	merge m:1 round cluster using `temp2', nogen
	
 recode kap_ (98=8)
 la def capital_value 8 "Don't know", modify
 
	*Preparing for outputing
	foreach var of varlist  firm_size act1_collapsed region  kap_ sex educlvl3 usocp1d_cat agegrp3  {
	
			levelsof `var', local(levels)
						
			capture gen  norm_`var'=.
	
			foreach l of local levels {
			
					di "`l'"
			
					replace norm_`var'=norm_`var'_`l' if `var'_`l'==1 // level and var name same

				}
		}
	
	
		foreach var of varlist  legal_state   firm_age relout_ non_relout_   {
	
			levelsof `var', local(levels)
						
			capture gen  norm_`var'=.
	
			foreach l of local levels {
			
					di "`l'"
					
					local k=`l'+1
					
					di "`k'"
			
					replace norm_`var'=norm_`var'_`k' if `var'_`k'==1

				}
		} 
	 
	 	
		foreach var of varlist  sloc_   {
	
		 
						
			capture gen  norm_`var'=.
	
			foreach l in 1 2 3 4 {
			
					di "`l'"
								
					replace norm_`var'=norm_`var'_`l' if `var'_`l'==1

				}
		} 
		
		foreach var of varlist ln_rev_wrk {
		
						capture replace `var'=1
						label define  `var' 1 "", modify 
						label val `var' `var'
		
					}
		
	
	label var act1_collapsed "Industry"
	label var region "Region"
	label var firm_age"Age of firm (years)"
	label var relout_ "Relatives outside the HH employed"
	label var non_relout_ "Non-relatives outside the HH employed"
	label var sloc_ "Location"
	label var educlvl3 "Owner's education"
	label var usocp1d_cat "Owner's occupation"
	label var agegrp3 "Owner's age group"
	label var sex "Owner's sex"
	
	*Output
	 tabout firm_size cluster  using "$output/ELMPS Cluster Table.xls", c( mean norm_firm_size) f(2)  clab(_)  replace sum    
	
	 foreach var of varlist act1_collapsed region legal_state  kap_ firm_age relout_ non_relout_ sloc_ sex educlvl3 usocp1d_cat agegrp3  {
	 
					 tabout `var' cluster  using "$output/ELMPS Cluster Table.xls", c(mean norm_`var') f(2)  clab(_)  append sum  
	 
			}
		
	
	
	 foreach var of varlist  ln_rev_wrk {
	 
					 tabout `var' cluster  using "$output/ELMPS Cluster Table.xls", c(mean std_`var') f(2)  clab(_)  append sum  
	 
			}
			
	gen n=1
	 
	label var n "N"
	label define n 1 "N", modify
	label val n n
	
	tabout n  cluster  using "$output/ELMPS Cluster Table.xls",  f(0)  clab(_)  append 
	
	tabout n  cluster [aw=weight]  using "$output/ELMPS Cluster Table.xls" , cells(row) f(2)  clab(_)  append 
	
*****************************************************************************************************************/
*SA: 5	
*****************************************************************************************************************/
	

	use "$workingdata/ELMPS_model2_3.dta", clear
	
	**informal
	
	keep if formality_basic==0
	
	**create binary variables
	foreach var of varlist firm_size act1_collapsed region legal_state  kap_ firm_age relout_ non_relout_ sloc_ sex educlvl3 usocp1d_cat agegrp3 {
	
				tab `var', gen(`var'_)
		 
	
			}
	
		**Check and sort on indentifier
	isid  hhid ent_num
	sort  hhid ent_num

			
	*Cluster for 5 groups, using gower (mixed cont. and binary)	
	cluster kmedians firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk ///
	, k(5) measure(gower) name(clusdirk1) start(krandom(67348))
		
	preserve
	
	collapse informal_m3_q? [aw=weight], by(clusdirk1)
	
	 
	*Order by descending
	egen cluster=rank(-informal_m3_q1)
	
	label var cluster "Cluster of Firms"

	*Label based on analysis
	label define cluster 1 "Illiterate women-owned" ///
						 2	"Blue collar" 3 "Urban retail" ///
						 4 "Secondary ed. owner" 5 "Larger firms", modify
	
	label val cluster cluster
	
	sort cluster
	
	keep clusdirk1 cluster
	
	tempfile temp1
	save `temp1'
	
	restore
	

	
	*Merge ordered clusters back into original data
	merge m:1 clusdirk1 using `temp1', nogen
	
	des cluster
	sum cluster
	tabu cluster [aw=weight]

	
	*Checks
	tabstat  firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk [aw=weight], by(cluster) stat(mean)
	
	
	tabstat  pr_model_3 [aw=weight], by(cluster) stat(mean)
	
	tab cluster informal_m3_q1 [aw=weight], nofreq row
	tab cluster informal_m3_q2 [aw=weight], nofreq row	
	tab cluster informal_m3_q3 [aw=weight], nofreq row
	tab cluster informal_m3_q4 [aw=weight], nofreq row
	
	
	
	*Graph distribution of quartiles over clusters
	graph hbar (mean) informal_m3_q? [aw=weight],   over(cluster,   label(labsize(small))) stack ylabel(,nogrid angle(0)) ///
	ytitle("Percent of informal firms") legend(order ( 1 "Quartile 1"  2 "Quartile 2"   3 "Quartile 3" 4 "Quartile 4")  ///
	size(small) col(4) rowgap(*1.5) symysize(*.8) symxsize(*.5)  pos(12)  ring(4) region(style(none)))  ///
	graphregion(color(white) fcolor(white) icolor(white) ifcolor(white) lcolor(white) ilcolor(white)) ///
	plotregion(margin(zero) color(white) fcolor(white) icolor(white) ifcolor(white) lcolor(white) ///
	ilcolor(white)) bar(1, color(gs11)) bar(2, color(gs8)) bar(3, color(gs4)) bar(4, color(gs0)) ///
	blabel(bar,format(%9.0f) position(center) size(vsmall) color(gs14))
	
		
	forval l=1/5 {
	
			forval j =1/4 {
	
					local i =  `j'+(5-`l')*4 
							
					foreach var of varlist informal_m3_q`j'    {
										
								sum `var' if cluster==`l' [aw=weight]  
										
								if r(mean)<2 {
									
										di "`l'"
										
										gr_edit .plotregion1.barlabels[`i'].Delete barlabels[`i'] edits
										
									}
							
							}
							}
		
				}
			
			

	 
	graph save "$output/SA 5 ELMPS Informal Firms by Cluster.gph", replace
	graph export "${output}/SA 5 ELMPS Informal Firms by Cluster.png", width(1500) replace			
 
	 
	**normalize variables for descriptives
	
	preserve 
	
	expand 2, gen(total)
	
	replace cluster=100 if total==1
	
	collapse (mean) firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk (sd) sd_ln_rev_wrk=ln_rev_wrk  [aw=weight], by(cluster round)
	
	drop if cluster==.
	
	sort round cluster
	
	*Ratio to mean for binary
	foreach var of varlist firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? {
	
				bys round: gen norm_`var'=`var'/`var'[_N] 

			}
	*Continuous standardized		
	foreach var of varlist ln_rev_wrk {
	
				bys round: gen std_`var'=(`var'-`var'[_N])/sd_`var'[_N]

			}	
			
	drop if cluster==100 
	
	tempfile temp2
	save `temp2'
	
	restore
	
	*Merging back in clusters
	merge m:1 round cluster using `temp2', nogen
	
 recode kap_ (98=8)
 la def capital_value 8 "Don't know", modify
 
	*Preparing for outputing
	foreach var of varlist  firm_size act1_collapsed region  kap_ sex educlvl3 usocp1d_cat agegrp3  {
	
			levelsof `var', local(levels)
						
			capture gen  norm_`var'=.
	
			foreach l of local levels {
			
					di "`l'"
			
					replace norm_`var'=norm_`var'_`l' if `var'_`l'==1 // level and var name same

				}
		}
	
	
		foreach var of varlist  legal_state   firm_age relout_ non_relout_   {
	
			levelsof `var', local(levels)
						
			capture gen  norm_`var'=.
	
			foreach l of local levels {
			
					di "`l'"
					
					local k=`l'+1
					
					di "`k'"
			
					replace norm_`var'=norm_`var'_`k' if `var'_`k'==1

				}
		} 
	 
	 	
		foreach var of varlist  sloc_   {
	
		 
						
			capture gen  norm_`var'=.
	
			foreach l in 1 2 3 4 {
			
					di "`l'"
								
					replace norm_`var'=norm_`var'_`l' if `var'_`l'==1

				}
		} 
		
		foreach var of varlist ln_rev_wrk {
		
						capture replace `var'=1
						label define  `var' 1 "", modify 
						label val `var' `var'
		
					}
		
	
	label var act1_collapsed "Industry"
	label var region "Region"
	label var firm_age"Age of firm (years)"
	label var relout_ "Relatives outside the HH employed"
	label var non_relout_ "Non-relatives outside the HH employed"
	label var sloc_ "Location"
	label var educlvl3 "Owner's education"
	label var usocp1d_cat "Owner's occupation"
	label var agegrp3 "Owner's age group"
	label var sex "Owner's sex"
	
	*Output
	 tabout firm_size cluster  using "$output/SA 5 ELMPS Cluster Table.xls", c( mean norm_firm_size) f(2)  clab(_)  replace sum    
	
	 foreach var of varlist act1_collapsed region legal_state  kap_ firm_age relout_ non_relout_ sloc_ sex educlvl3 usocp1d_cat agegrp3  {
	 
					 tabout `var' cluster  using "$output/SA 5 ELMPS Cluster Table.xls", c(mean norm_`var') f(2)  clab(_)  append sum  
	 
			}
		
	
	
	 foreach var of varlist  ln_rev_wrk {
	 
					 tabout `var' cluster  using "$output/SA 5 ELMPS Cluster Table.xls", c(mean std_`var') f(2)  clab(_)  append sum  
	 
			}
			
	gen n=1
	 
	label var n "N"
	label define n 1 "N", modify
	label val n n
	
	tabout n  cluster  using "$output/SA 5 ELMPS Cluster Table.xls",  f(0)  clab(_)  append 
	
	tabout n  cluster [aw=weight]  using "$output/SA 5 ELMPS Cluster Table.xls" , cells(row) f(2)  clab(_)  append 
	
*****************************************************************************************************************/
*SA 15 	
*****************************************************************************************************************/
	
	
	use "$workingdata/ELMPS_model2_3.dta", clear
	
	**informal
	
	keep if formality_basic==0
	
	**create binary variables
	foreach var of varlist firm_size act1_collapsed region legal_state  kap_ firm_age relout_ non_relout_ sloc_ sex educlvl3 usocp1d_cat agegrp3 {
	
				tab `var', gen(`var'_)
		 
	
			}
	
		**Check and sort on indentifier
	isid  hhid ent_num
	sort  hhid ent_num

			
	*Cluster for 15 groups, using gower (mixed cont. and binary)	
	cluster kmedians firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk ///
	, k(15) measure(gower) name(clusdirk1) start(krandom(67348))
		
	preserve
	
	collapse informal_m3_q? [aw=weight], by(clusdirk1)
	
	 
	*Order by descending
	egen cluster=rank(-informal_m3_q1)
	
	label var cluster "Cluster of Firms"
 
	*Label based on analysis
	label define cluster 1 "New illiterate women-owned rural" ///
						 2	"Women-owned shops" 3 "Older women-owned" 4 "Rural Upper young owner" 5 "Blue collar manuf. & transp." ///
						 4 "Women-owned high-rev. urban" 5 "Blue-collar workshop" 6 "Blue collar construction" 7 "Young male-owned prof." 8 "Rural Lwr. sec. male-owned" 9 "Urban male high-rev." 10 "Other sec. male-owned" 11 "Two-person firms" 12 "Larger older non-metro." 13 "Larger non-Cairo workshops" 14 "Larger urban high-capital" 15 "Larger higher ed. prof.", modify
	label val cluster cluster
	
	sort cluster
	
	keep clusdirk1 cluster
	
	tempfile temp1
	save `temp1'
	
	restore
	

	
	*Merge ordered clusters back into original data
	merge m:1 clusdirk1 using `temp1', nogen
	
	des cluster
	sum cluster
	tabu cluster [aw=weight]

	
	*Checks
	tabstat  firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk [aw=weight], by(cluster) stat(mean)
	
	
	tabstat  pr_model_3 [aw=weight], by(cluster) stat(mean)
	
	tab cluster informal_m3_q1 [aw=weight], nofreq row
	tab cluster informal_m3_q2 [aw=weight], nofreq row	
	tab cluster informal_m3_q3 [aw=weight], nofreq row
	tab cluster informal_m3_q4 [aw=weight], nofreq row
	
	
	
	*Graph distribution of quartiles over clusters
	graph hbar (mean) informal_m3_q? [aw=weight],   over(cluster,   label(labsize(small))) stack ylabel(,nogrid angle(0)) ///
	ytitle("Percent of informal firms") legend(order ( 1 "Quartile 1"  2 "Quartile 2"   3 "Quartile 3" 4 "Quartile 4")  ///
	size(small) col(4) rowgap(*1.5) symysize(*.8) symxsize(*.5)  pos(12)  ring(4) region(style(none)))  ///
	graphregion(color(white) fcolor(white) icolor(white) ifcolor(white) lcolor(white) ilcolor(white)) ///
	plotregion(margin(zero) color(white) fcolor(white) icolor(white) ifcolor(white) lcolor(white) ///
	ilcolor(white)) bar(1, color(gs11)) bar(2, color(gs8)) bar(3, color(gs4)) bar(4, color(gs0)) ///
	blabel(bar,format(%9.0f) position(center) size(vsmall) color(gs14))
	
		
	forval l=1/15 {
	
			forval j =1/4 {
	
					local i =  `j'+(15-`l')*4 
							
					foreach var of varlist informal_m3_q`j'    {
										
								sum `var' if cluster==`l' [aw=weight]  
										
								if r(mean)<2 {
									
										di "`l'"
										
										gr_edit .plotregion1.barlabels[`i'].Delete barlabels[`i'] edits
										
									}
							
							}
							}
		
				}
			
			

	 
	graph save "$output/SA 15 ELMPS Informal Firms by Cluster.gph", replace
	graph export "${output}/SA 15 ELMPS Informal Firms by Cluster.png", width(1500) replace			
 
	 
	**normalize variables for descriptives
	
	preserve 
	
	expand 2, gen(total)
	
	replace cluster=100 if total==1
	
	collapse (mean) firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? ln_rev_wrk (sd) sd_ln_rev_wrk=ln_rev_wrk  [aw=weight], by(cluster round)
	
	drop if cluster==.
	
	sort round cluster
	
	*Ratio to mean for binary
	foreach var of varlist firm_size_? act1_collapsed_? region_? legal_state_?  kap__? firm_age_* relout__? non_relout__? sloc__? sex_? educlvl3_? usocp1d_cat_? agegrp3_? {
	
				bys round: gen norm_`var'=`var'/`var'[_N] 

			}
	*Continuous standardized		
	foreach var of varlist ln_rev_wrk {
	
				bys round: gen std_`var'=(`var'-`var'[_N])/sd_`var'[_N]

			}	
			
	drop if cluster==100 
	
	tempfile temp2
	save `temp2'
	
	restore
	
	*Merging back in clusters
	merge m:1 round cluster using `temp2', nogen
	
 recode kap_ (98=8)
 la def capital_value 8 "Don't know", modify
 
	*Preparing for outputing
	foreach var of varlist  firm_size act1_collapsed region  kap_ sex educlvl3 usocp1d_cat agegrp3  {
	
			levelsof `var', local(levels)
						
			capture gen  norm_`var'=.
	
			foreach l of local levels {
			
					di "`l'"
			
					replace norm_`var'=norm_`var'_`l' if `var'_`l'==1 // level and var name same

				}
		}
	
	
		foreach var of varlist  legal_state   firm_age relout_ non_relout_   {
	
			levelsof `var', local(levels)
						
			capture gen  norm_`var'=.
	
			foreach l of local levels {
			
					di "`l'"
					
					local k=`l'+1
					
					di "`k'"
			
					replace norm_`var'=norm_`var'_`k' if `var'_`k'==1

				}
		} 
	 
	 	
		foreach var of varlist  sloc_   {
	
		 
						
			capture gen  norm_`var'=.
	
			foreach l in 1 2 3 4 {
			
					di "`l'"
								
					replace norm_`var'=norm_`var'_`l' if `var'_`l'==1

				}
		} 
		
		foreach var of varlist ln_rev_wrk {
		
						capture replace `var'=1
						label define  `var' 1 "", modify 
						label val `var' `var'
		
					}
		
	
	label var act1_collapsed "Industry"
	label var region "Region"
	label var firm_age"Age of firm (years)"
	label var relout_ "Relatives outside the HH employed"
	label var non_relout_ "Non-relatives outside the HH employed"
	label var sloc_ "Location"
	label var educlvl3 "Owner's education"
	label var usocp1d_cat "Owner's occupation"
	label var agegrp3 "Owner's age group"
	label var sex "Owner's sex"
	
	*Output
	 tabout firm_size cluster  using "$output/SA 15 ELMPS Cluster Table.xls", c( mean norm_firm_size) f(2)  clab(_)  replace sum    
	
	 foreach var of varlist act1_collapsed region legal_state  kap_ firm_age relout_ non_relout_ sloc_ sex educlvl3 usocp1d_cat agegrp3  {
	 
					 tabout `var' cluster  using "$output/SA 15 ELMPS Cluster Table.xls", c(mean norm_`var') f(2)  clab(_)  append sum  
	 
			}
		
	
	
	 foreach var of varlist  ln_rev_wrk {
	 
					 tabout `var' cluster  using "$output/SA 15 ELMPS Cluster Table.xls", c(mean std_`var') f(2)  clab(_)  append sum  
	 
			}
			
	gen n=1
	 
	label var n "N"
	label define n 1 "N", modify
	label val n n
	
	tabout n  cluster  using "$output/SA 15 ELMPS Cluster Table.xls",  f(0)  clab(_)  append 
	
	tabout n  cluster [aw=weight]  using "$output/SA 15 ELMPS Cluster Table.xls" , cells(row) f(2)  clab(_)  append 
	



