/******************************************************************************************************************
*Title: EFIEW ELMPS Grouping Analysis
*Created by: KWR
*Created on: March 15, 2020
*Last Modified on:  May 19, 2022
*Last Modified by:  CK
*Purpose : Use EFIEW ELMPS Model 3, created predicted probabilities, then do grouping analysis
	
*****************************************************************************************************************/
	capture log close
	
	log using "$log/EFIEW ELMPS Grouping Analysis.txt", replace

	use "$workingdata/ELMPS_model2_3.dta", clear

	**grouping
	
	**variables for grouping
	*Three part firm size
	clonevar firm_size_new=firm_size
	recode firm_size_new (3 4 = 3)
	
	label define firm_size_new 1 "1" 2 "2" 3 "3-24" , modify
	label value firm_size_new firm_size_new 
	label variable firm_size_new "Number of employees" 
	
	*Binary firm age
	clonevar firm_age_new=firm_age
	recode firm_age_new (0/4=1) (5/11=2)  
		
	label define firm_age_new 1 "Less than 5 years" 2  "5 years or above", modify
	label value firm_age_new firm_age_new 
	label variable firm_age_new "Firm age at time of survey"
	
	*Quartiles of log rev. 
	xtile ln_rev_wrk_qrtl=ln_rev_wrk [aw=weight], nq(4)

	label variable ln_rev_wrk_qrtl "Quartile of  Ln net revenue per worker"
	
	*Binary owner ed. 
	clonevar owner_edu=educlvl3
	
	recode owner_edu (1 2=1) (3 4=2)
	
	label define owner_edu 1 "Below secondary" 2 "Secondary +", modify
	label val owner_edu owner_edu
	
	**Groups: firm size, firm age, non relative hire or not (non_relout_),ln_rev_wrk_qrtl, owner_edu 
	egen profile_groups=group(firm_size_new firm_age_new  non_relout_ ln_rev_wrk_qrtl owner_edu)

	
	drop if profile_groups==.
	drop if pr_model_3==.

	*N counter
	gen informal=1
	
*Keep relevant variables	
	order profile_groups firm_size_new firm_age_new  non_relout_ ln_rev_wrk_qrtl owner_edu  informal informal_m3_q? 
	
		forval i=1/4 {
		
		clonevar pct_informal_m3_q`i'=informal_m3_q`i'
		replace informal_m3_q`i'=informal_m3_q`i'/100
	
	}
	
	**generate weighted N for each group [the following collapse creates unweighted total N as the weights are applied in the by()]
	
	preserve
	
	tab profile_groups [aw=weight], matcell(wg_informal)
	
	matrix list wg_informal
	
	bys profile_groups: gen first_i_of_group=_n
	
	keep if first_i_of_group==1
	
	svmat wg_informal
	
	rename wg_informal1 wg_informal
	
	keep profile_groups wg_informal
	
	tempfile temp1
	save `temp1'
	
	restore
 
	**grouping - sum for N
	collapse (sum) informal informal_m3_q? [aw=weight], by(profile_groups firm_size_new firm_age_new   non_relout_ ln_rev_wrk_qrtl owner_edu)
	
	**now merge with temp1 to fetch the weighted sum for each group
	merge 1:1 profile_groups using `temp1', nogen
	
	sort firm_size_new firm_age_new non_relout_ ln_rev_wrk_qrtl owner_edu    

	**we will do multiple iterations to aggregate. First, if cell<10, first aggregate for revenue_qrtl with the group of the other quartile on the same side of median, 
	gen cell_size_less10=informal<10
	
	gen ln_rev_wrk_median=inlist(ln_rev_wrk_qrtl,1,2)
	recode ln_rev_wrk_median (0=2)
	
	bys firm_size_new firm_age_new   non_relout_ ln_rev_wrk_median owner_edu: egen within_median_cell_size_less10=total(cell_size_less10)
	
	
	replace ln_rev_wrk_qrtl=5 if inlist(ln_rev_wrk_qrtl,1,2) & inlist(within_median_cell_size_less10,1,2) 
	replace ln_rev_wrk_qrtl=6 if inlist(ln_rev_wrk_qrtl,3,4) & inlist(within_median_cell_size_less10,1,2) 
	
	label define ln_rev_wrk_qrtl 1 "1" 2 "2" 3 "3" 4 "4" 5 "1 & 2 (aggregate)" 6 "3 & 4 (aggregate)", modify
	
	label val ln_rev_wrk_qrtl ln_rev_wrk_qrtl
	
	*Revise by weights
	
	foreach num of numlist 1/4 {
	replace informal_m3_q`num'=informal_m3_q`num'/informal*wg_informal
	}
	
	*Sum up/weighted ave in new collapsed categories
	collapse (sum) wg_informal informal informal_m3_q?, by(firm_size_new firm_age_new   non_relout_ ln_rev_wrk_qrtl owner_edu)

	**then education
	gen cell_size_less10=informal<10
	
	gen ln_rev_wrk_median=inlist(ln_rev_wrk_qrtl,1,2,5)
	recode ln_rev_wrk_median (0=2)
		
	gen all_education=1
 
	bys firm_size_new firm_age_new  non_relout_ ln_rev_wrk_median all_education : egen all_education10=total(cell_size_less10)
	
	replace owner_edu=5 if inlist(all_education10,1,2)
	replace ln_rev_wrk_qrtl=5 if inlist(ln_rev_wrk_qrtl,1,2) & inlist(all_education10,1,2) 
	replace ln_rev_wrk_qrtl=6 if inlist(ln_rev_wrk_qrtl,3,4) & inlist(all_education10,1,2) 
		
	label define owner_edu 5 "All education (aggregate)", modify

	*Sum up in new collapsed categories
	collapse (sum) wg_informal informal  informal_m3_q? , by(firm_size_new firm_age_new   non_relout_ ln_rev_wrk_qrtl owner_edu)
	
	**then ln revenue per worker again
	gen cell_size_less10=informal<10
	
	gen ln_rev_wrk_all=1
	
	gen all_education=1
 	
	bys firm_size_new firm_age_new  non_relout_ ln_rev_wrk_all all_education: egen rev_cell_size_less10=total(cell_size_less10)
	
	replace ln_rev_wrk_qrtl=7 if inlist(rev_cell_size_less10,1,2) 
	replace owner_edu=5 if inlist(rev_cell_size_less10,1,2)
	
	label define ln_rev_wrk_qrtl 7 "All quartile (aggregate)", modify
	
	*Sum up in new collapsed categories
	collapse (sum) wg_informal informal  informal_m3_q? , by(firm_size_new firm_age_new  non_relout_ ln_rev_wrk_qrtl owner_edu)
		
	**then non_relout_
	gen cell_size_less10=informal<10
	
	gen non_relout_all=1
	gen ln_rev_wrk_all=1
	gen all_education=1
 
		
	bys firm_size_new firm_age_new  non_relout_all ln_rev_wrk_all all_education: egen non_relout_cell_size_less10=total(cell_size_less10)
	
	
	replace non_relout_=2 if inlist(non_relout_cell_size_less10,1,2) 
  la def yn1 2 "Both (aggregate)", modify
  
	replace ln_rev_wrk_qrtl=7 if inlist(non_relout_cell_size_less10,1,2) 
	replace owner_edu=5 if inlist(non_relout_cell_size_less10,1,2)
	
	label define  yes_no 2 "All (aggregate)", modify
	
*Sum up in new collapsed categories
	collapse (sum) wg_informal informal  informal_m3_q? , by(firm_size_new firm_age_new  non_relout_ ln_rev_wrk_qrtl owner_edu)	
	
*Divide by N to recover from summing	
	foreach q in 1 2 3 4 {
	
				gen pct_informal_m3_q`q'=100*informal_m3_q`q'/wg_informal , after(informal_m3_q`q')
	
	
			}
			
	drop informal_m3_q?
	
	gsort -pct_informal_m3_q1 -pct_informal_m3_q2 -pct_informal_m3_q3 -pct_informal_m3_q4 firm_size_new firm_age_new  non_relout_ ln_rev_wrk_qrtl owner_edu
	
	gen profile_groups=_n
	
	sum wg_informal
	
	gen pct_wg_informal=100*wg_informal/`r(sum)' 
	
	drop wg_informal
	
	export excel using "$output/Model 3 ELMPS percent of informal firms in each profile group.xls", firstrow(var) replace  
	
	

 
