/******************************************************************************************************************
*Title: EFIEW Models SA
*Created by: CGK
*Created on: 2023.03.05
*Last Modified on: 2023.03.05
*Last Modified by: CGK
*Purpose : Regression models SA

*****************************************************************************************************************/
	capture log close
	
	log using "$log/EFIEW Models SA $S_DATE.txt", replace


	use "$workingdata/ELMPS_Harmonized", clear
	
** In establishment only
keep if is_est==1	
	
	
*************
*Model 3
*************		
	
*Original reference
	logit formality_basic  ib1.firm_size  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk b1.firm_age ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or	
	
*SA: continuous workers		
		
	logit formality_basic  c.number_of_employees  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk b1.firm_age ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or
	 
*SA: logged workers
gen ln_num_emp=ln(number_of_employees)	
 
	logit formality_basic  c.ln_num_emp  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk b1.firm_age ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or
	 	 
*SA: continuous age and dummy DK 
gen firm_age_dk=firm_age==11 if firm_age!=.
sum c_firm_age [aw=weight]
replace c_firm_age=`r(mean)' if firm_age_dk==1

	logit formality_basic ib1.firm_size c.c_firm_age i.firm_age_dk  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or		 
		 
*SA logged age and dummy DK
gen ln_firm_age=ln(c_firm_age)	

	logit formality_basic ib1.firm_size c.ln_firm_age i.firm_age_dk  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or		
	 
*SA quadratic
	logit formality_basic ib1.firm_size c.c_firm_age##c.c_firm_age i.firm_age_dk  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or		 
	 
	 
*SA present

	logit formality_basic c.number_of_employees c.c_firm_age##c.c_firm_age i.firm_age_dk  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or		 
	 	 
	 	estimates store estmodel3SA
	
		margins, predict(pr) at(number_of_employees=0 act1_collapsed=3 region=1 legal_state=1 kap_=1 ln_rev_wrk=0 firm_age=0 relout_=0 non_relout_=0 sloc=2 sex=1 educlvl3=1 usocp1d_cat=1 agegrp3=1) post
	
matrix define m3=(e(b))

		

	
*Estimation table
esttab  estmodel3SA  using "$output/estmodel3_SA.csv", ///
cells(b(star fmt(%9.3f)) se(par))  ///
stats(N r2_p, fmt(%9.0g %9.3f)) label  ///
nobase noomit  interact(*) ///
refcat( ///
1.act1_collapsed "Industry (wholesale/retail omit.)" ///
2.region "Region (Greater Cairo omit.)"  ///
2.capital "Capital (less than 5000 omit.)" ///
0.legal_state "Partnership (sole proprietorship omit.)" ///
2.kap_ "Capital (none omit.)" ///
1.relout_ "Relatives outside the HH employed (no omit.)" ///
1.non_relout_ "Non-relatives outside the HH employed (no omit.)" ///
3.sloc_ "Type of workplace (shop omit.)" 2.sex "Sex (male omit.)" ///
2.educlvl3 "Education (illit. omit.)" 2.usocp1d_cat "Occupation (prof./tech. omit.)" ///
coeflabel(number_of_employees "Firm size (continuous)" c_firm_age "Firm age") ///
2.agegrp3 "Age group (<30 omit.)" ///
 , nolabel) ///
 order(number_of_employees  *.act1_collapsed *.region *.legal_state *.kap_ ln_rev_wrk *firm_age* 	 1.relout_ 1.non_relout_ *.sloc_ 2.sex *.educlvl3 *.usocp1d_cat *.agegrp3   ) replace eform 
 
estout matrix(m3) using "$output/estmodel3_SA.csv", append
 
*Predicted probabilities

foreach num of numlist 3 {
estimates restore estmodel`num'SA
predict pr_model_`num'
}



*Generate density at various probabilities
	
foreach num1 of numlist 1/0 {
foreach num of numlist 3 {	
kdensity pr_model_`num' if formality_basic==`num1' [aw=weight], bw(.05) ///
 gen(kd_model_`num'_`num1'_x kd_model_`num'_`num1'_d) nograph 
 
 }
 }
 
*Find cross

foreach num of numlist 3 {	

gen cross_model_`num'=.
replace cross_model_`num'=1 if (kd_model_`num'_0_d[_n-1]> kd_model_`num'_1_d[_n-1]) ///
& (kd_model_`num'_0_d[_n]< kd_model_`num'_1_d[_n])
 
}

*Double check that there is only one cross
foreach num of numlist 3 {
count if cross_model_`num'!=.
assert r(N)==1
} 

foreach num of numlist 3 {
replace cross_model_`num'=1 if cross_model_`num'==. & cross_model_`num'[_n-1]==1 
replace cross_model_`num'=0 if cross_model_`num'==. & (cross_model_`num'[_n-1]==. | cross_model_`num'[_n-1]==0) 
} 


*Area of overlap is formal below cross and informal above cross

foreach num of numlist 3 {
gen overlap_`num'=kd_model_`num'_1_d*(kd_model_`num'_1_x[_n]-kd_model_`num'_1_x[_n-1]) if cross_model_`num'==0
replace overlap_`num'=kd_model_`num'_0_d*(kd_model_`num'_0_x[_n]-kd_model_`num'_0_x[_n-1]) if cross_model_`num'==1
}



scalar list

*Graph

foreach num of numlist 3 {	

graph twoway kdensity pr_model_`num' if formality_basic==0 [aw=weight], ///
 lcolor(gs10) lpatt("l") bw(.05)  ///
 || kdensity pr_model_`num' if formality_basic==1 [aw=weight], ///
 lcolor(gs3) lpatt("l") bw(.05) ///
 , note("") xtitle("Probability formal") ///
ytitle("Density") legend(label(1 "Informal") label(2 "Formal")) ///
plotregion(margin(zero)) xlabel(0(.2)1) ///
ylabel(0(.5)4) title("Model `num' in est.")

sum overlap_`num'
local overlap=int(round(r(sum),.01)*100)
di `overlap'

gr_edit .plotregion1.AddTextBox added_text editor .5 .35
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush ".`overlap' overlap"

graph save "$output/model `num' predict_`num' SA.gph", replace  
	graph export "$output/model `num' predict_`num' SA.png",  replace width(1500)
	
}
	
	log close 	
