/******************************************************************************************************************
*Title: EFIEW Models
*Created by: CGK
*Created on: February 22, 2020
*Last Modified on: May 18, 2020
*Last Modified by: CGK
*Purpose : Regression models

*****************************************************************************************************************/
	capture log close
	
	log using "$log/EFIEW Models $S_DATE.txt", replace

***************
** Model 1
***************

	
	**Run regression
	
	use "$workingdata/ELMPS_Harmonized", clear
	
	*Pooled
	logit formality_basic ib1.firm_size ib2.sloc ib3.act1_collapsed ib1.region ///
	[pw=weight], or
	
	estimates store estmodel1
	
	*By establishment
	foreach num of numlist 0/1 {
	logit formality_basic  ib1.firm_size ib2.sloc ib3.act1_collapsed ib1.region [pw=weight] if is_est==`num', or
	
	estimates store estmodel1_`num'
	}
	
	
*Estimation table
esttab estmodel1 estmodel1_* using "$output/estmodel1.csv", ///
cells(b(star fmt(%9.3f)) se(par))  ///     
stats(N r2_p, fmt(%9.0g %9.3g)) label  ///
nobase noomit ///
interact(*) ///
refcat(2.firm_size "Ent. size (one worker omit.)" ///
1.sloc_ "Type of workplace (shop omit. for all firms and in est. vehicle omit. for out of est.)" ///
1.act1_collapsed "Industry (wholesale/retail omit.)" ///
2.region "Region (Greater Cairo omit.)"  ///
 , nolabel) ///
 mlabel("All firms" "Out of est." ///
           "In est." ) ///
replace eform

*Predicted probabilities

foreach num of numlist 0/1 {
estimates restore estmodel1_`num'
predict pr_model1_`num' if is_est==`num'
}

estimates restore estmodel1
predict pr_model1_2 


*Predicted probabilities for reference
*Pooled
sum pr_model1_2 if firm_size==1 & sloc==2 & act1_collapsed==3 & region==1

matrix m_1_2=(`r(mean)')

*In est. 
sum pr_model1_1 if is_est==1 & firm_size==1 & sloc==2 & act1_collapsed==3 & region==1

matrix m_1_1=(`r(mean)')

*Out est. 
sum pr_model1_0 if is_est==0 & firm_size==1 & sloc==7 & act1_collapsed==3 & region==6

matrix m_1_0=(`r(mean)')

matrix  m1=(m_1_2, m_1_0,m_1_1)

estout matrix(m1) using "$output/estmodel1.csv", append

*Generate density at various probabilities

foreach num of numlist 0/2 {	

kdensity pr_model1_`num' [aw=weight], bw(.05) ///
 gen(kd_model1_`num'_x kd_model1_`num'_d) nograph 
 
	
foreach num1 of numlist 1/0 {
kdensity pr_model1_`num' if formality_basic==`num1' [aw=weight], bw(.05) ///
 gen(kd_model1_`num'_`num1'_x kd_model1_`num'_`num1'_d) ///
 at(kd_model1_`num'_x) nograph 
 
 }
 }

*Find cross

foreach num of numlist 0/2 {	

gen cross_model1_`num'=.
replace cross_model1_`num'=1 if (kd_model1_`num'_0_d[_n-1]> kd_model1_`num'_1_d[_n-1]) ///
& (kd_model1_`num'_0_d[_n]< kd_model1_`num'_1_d[_n])
 
}

*Double check that there is only one cross
foreach num of numlist 0/2 {
count if cross_model1_`num'!=.
assert r(N)==1
} 

foreach num of numlist 0/2 {
replace cross_model1_`num'=1 if cross_model1_`num'==. & cross_model1_`num'[_n-1]==1 
replace cross_model1_`num'=0 if cross_model1_`num'==. & (cross_model1_`num'[_n-1]==. | cross_model1_`num'[_n-1]==0) 
} 


*Area of overlap is formal below cross and informal above cross

foreach num of numlist 0/2 {
gen overlap_`num'=kd_model1_`num'_1_d*(kd_model1_`num'_1_x[_n]-kd_model1_`num'_1_x[_n-1]) if cross_model1_`num'==0
replace overlap_`num'=kd_model1_`num'_0_d*(kd_model1_`num'_0_x[_n]-kd_model1_`num'_0_x[_n-1]) if cross_model1_`num'==1
}



scalar list


*Graph


foreach num of numlist 0/2 {
	if 	`num'==0 {
		local title "Outside Est."
	}
	if 	`num'==1 {
		local title "In Est."
	}
		if 	`num'==2 {
		local title "Total"
	}
	
graph twoway kdensity pr_model1_`num' if formality_basic==0 [aw=weight], ///
 lcolor(gs10) lpatt("l") bw(.05)  ///
 || kdensity pr_model1_`num' if formality_basic==1 [aw=weight], ///
 lcolor(gs3) lpatt("l") bw(.05) ///
 , note("") xtitle("Probability formal") ///
ytitle("Density") legend(label(1 "Informal") label(2 "Formal")) ///
plotregion(margin(zero)) xlabel(0(.2)1) ///
ylabel(0(.5)4) title("`title'")

sum overlap_`num'
local overlap=string(round(r(sum),.01),"%9.2f")
di `overlap'

gr_edit .plotregion1.AddTextBox added_text editor 1 .35
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush "`overlap' overlap"

graph save "$output/model 1 predict_`num'.gph", replace  
	graph export "$output/model 1 predict_`num'.png",  replace width(1500)
	
}

grc1leg "$output/model 1 predict_0.gph" "$output/model 1 predict_1.gph" ///
"$output/model 1 predict_2.gph"

graph save "$output/model 1 predict.gph", replace  
	graph export "$output/model 1 predict.png",  replace width(1500)
	

********
**to calculate what fraction of informal firms are there in each quartile of predicted probablity
********

keep if formality_basic==0
 
 
 
foreach num of numlist 0/2 {

foreach num2 of numlist 1/4 {

gen informal_m`num'_q`num2'=.
}


		replace informal_m`num'_q1=(pr_model1_`num'<.25 )*100 if	pr_model1_`num'!=.
		replace informal_m`num'_q2=(pr_model1_`num'>=.25 &  pr_model1_`num'<.5  )*100 if	pr_model1_`num'!=.
		replace informal_m`num'_q3=(pr_model1_`num'>=.5  &  pr_model1_`num'<.75 )*100 if	pr_model1_`num'!=.
		replace informal_m`num'_q4=(pr_model1_`num'>=.75)*100  if	pr_model1_`num'!=.
}


tabout is_est [aw=weight] using "$output/Model 1 percent of informal firms by quartiles of predicted probability.xls", ///
cells(mean informal_m0_q1 mean informal_m0_q2 mean informal_m0_q3 mean informal_m0_q4 mean informal_m1_q1 mean informal_m1_q2 mean informal_m1_q3 mean informal_m1_q4 mean informal_m2_q1 mean informal_m2_q2 mean informal_m2_q3 mean informal_m2_q4 ) replace sum oneway f(1)

***************
** Model 2/3 in establishment
***************

		
	use "$workingdata/ELMPS_Harmonized", clear
	
	** In establishment only
keep if is_est==1	

*************
*Model 2
*************		
		
	logit formality_basic  ib1.firm_size  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk b1.firm_age ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 [pw=weight], or
	
	
	estimates store estmodel2
	
	margins, predict(pr) at(firm_size=1 act1_collapsed=3 region=1 legal_state=1 kap_=1 ln_rev_wrk=0 firm_age=1 relout_=0 non_relout_=0 sloc=2) post
	
matrix define m2=(e(b))
	

*************
*Model 3
*************		
		
	logit formality_basic  ib1.firm_size  ib3.act1_collapsed ib1.region ///
	 ib1.legal_state ///
	 ib1.kap_ c.ln_rev_wrk b1.firm_age ///
	 i.relout_ i.non_relout_ b2.sloc_ /// 
	 i.sex i.educlvl3 i.usocp1d_cat i.agegrp3 ///
	 [pw=weight], or
	 
	 	estimates store estmodel3
	
		margins, predict(pr) at(firm_size=1 act1_collapsed=3 region=1 legal_state=1 kap_=1 ln_rev_wrk=0 firm_age=1 relout_=0 non_relout_=0 sloc=2 sex=1 educlvl3=1 usocp1d_cat=1 agegrp3=1) post
	
matrix define m3=(m2, e(b))

		

	
*Estimation table
esttab estmodel2  estmodel3  using "$output/estmodel2_3_all.csv", ///
cells(b(star fmt(%9.3f)) se(par))  ///
stats(N r2_p, fmt(%9.0g %9.3f)) label  ///
nobase noomit  interact(*) ///
refcat(2.firm_size "Ent. size (one worker omit.)" ///
1.act1_collapsed "Industry (wholesale/retail omit.)" ///
2.region "Region (Greater Cairo omit.)"  ///
2.capital "Capital (less than 5000 omit.)" ///
0.legal_state "Partnership (sole proprietorship omit.)" ///
2.kap_ "Capital (none omit.)" 0.firm_age "Ent. age (one year old omit.)" ///
1.relout_ "Relatives outside the HH employed (no omit.)" ///
1.non_relout_ "Non-relatives outside the HH employed (no omit.)" ///
3.sloc_ "Type of workplace (shop omit.)" 2.sex "Sex (male omit.)" ///
2.educlvl3 "Education (illit. omit.)" 2.usocp1d_cat "Occupation (prof./tech. omit.)" ///
2.agegrp3 "Age group (<30 omit.)" ///
 , nolabel) ///
 order(*.firm_size  *.act1_collapsed *.region *.legal_state *.kap_ ln_rev_wrk *.firm_age 	 1.relout_ 1.non_relout_ *.sloc_ 2.sex *.educlvl3 *.usocp1d_cat *.agegrp3   ) replace eform 
 
estout matrix(m3) using "$output/estmodel2_3_all.csv", append
 
*Predicted probabilities

foreach num of numlist 2/3 {
estimates restore estmodel`num'
predict pr_model_`num'
}



*Generate density at various probabilities
	
foreach num1 of numlist 1/0 {
foreach num of numlist 2/3 {	
kdensity pr_model_`num' if formality_basic==`num1' [aw=weight], bw(.05) ///
 gen(kd_model_`num'_`num1'_x kd_model_`num'_`num1'_d) nograph 
 
 }
 }
 
*Find cross

foreach num of numlist 2/3 {	

gen cross_model_`num'=.
replace cross_model_`num'=1 if (kd_model_`num'_0_d[_n-1]> kd_model_`num'_1_d[_n-1]) ///
& (kd_model_`num'_0_d[_n]< kd_model_`num'_1_d[_n])
 
}

*Double check that there is only one cross
foreach num of numlist 2/3 {
count if cross_model_`num'!=.
assert r(N)==1
} 

foreach num of numlist 2/3 {
replace cross_model_`num'=1 if cross_model_`num'==. & cross_model_`num'[_n-1]==1 
replace cross_model_`num'=0 if cross_model_`num'==. & (cross_model_`num'[_n-1]==. | cross_model_`num'[_n-1]==0) 
} 


*Area of overlap is formal below cross and informal above cross

foreach num of numlist 2/3 {
gen overlap_`num'=kd_model_`num'_1_d*(kd_model_`num'_1_x[_n]-kd_model_`num'_1_x[_n-1]) if cross_model_`num'==0
replace overlap_`num'=kd_model_`num'_0_d*(kd_model_`num'_0_x[_n]-kd_model_`num'_0_x[_n-1]) if cross_model_`num'==1
}



scalar list

*Graph

foreach num of numlist 2/3 {	

graph twoway kdensity pr_model_`num' if formality_basic==0 [aw=weight], ///
 lcolor(gs10) lpatt("l") bw(.05)  ///
 || kdensity pr_model_`num' if formality_basic==1 [aw=weight], ///
 lcolor(gs3) lpatt("l") bw(.05) ///
 , note("") xtitle("Probability formal") ///
ytitle("Density") legend(label(1 "Informal") label(2 "Formal")) ///
plotregion(margin(zero)) xlabel(0(.2)1) ///
ylabel(0(.5)4) title("Model `num' in est.")

sum overlap_`num'
local overlap=int(round(r(sum),.01)*100)
di `overlap'

gr_edit .plotregion1.AddTextBox added_text editor .5 .35
gr_edit .plotregion1.added_text_new = 1
gr_edit .plotregion1.added_text_rec = 1
gr_edit .plotregion1.added_text[1].style.editstyle  angle(default) size(medsmall) color(black) horizontal(left) vertical(middle) margin(zero) linegap(zero) drawbox(no) boxmargin(zero) fillcolor(bluishgray) linestyle( width(thin) color(black) pattern(solid)) box_alignment(east) editcopy
gr_edit .plotregion1.added_text[1].text = {}
gr_edit .plotregion1.added_text[1].text.Arrpush ".`overlap' overlap"

graph save "$output/model `num' predict_`num'.gph", replace  
	graph export "$output/model `num' predict_`num'.png",  replace width(1500)
	
}

grc1leg "$output/model 2 predict_2.gph" "$output/model 3 predict_3.gph" 

graph save "$output/model 2 3 predict ELMPS.gph", replace  
	graph export "$output/model 2 3 predict ELMPS.png",  replace width(1500)
	


********
**to calculate what fraction of informal firms are there in each quartile of predicted probablity
********


keep if formality_basic==0
	
foreach num of numlist 2/3 {

foreach num2 of numlist 1/4 {

gen informal_m`num'_q`num2'=.
}


		replace informal_m`num'_q1=(pr_model_`num'<.25 )*100 if	pr_model_`num'!=.
		replace informal_m`num'_q2=(pr_model_`num'>=.25 &  pr_model_`num'<.5  )*100 if	pr_model_`num'!=.
		replace informal_m`num'_q3=(pr_model_`num'>=.5  &  pr_model_`num'<.75 )*100 if	pr_model_`num'!=.
		replace informal_m`num'_q4=(pr_model_`num'>=.75)*100  if	pr_model_`num'!=.
}



tabout round [aw=weight] using "$output/Model 2 3 ELMPS percent of informal firms by quartiles of predicted probability.xls", ///
cells(mean informal_m2_q1 mean informal_m2_q2 mean informal_m2_q3 mean informal_m2_q4  mean informal_m3_q1 mean informal_m3_q2 mean informal_m3_q3 mean informal_m3_q4 ) replace sum oneway f(1)
	
save "$workingdata/ELMPS_model2_3.dta", replace	
	
	
	log close 	
